poLCA.updatePrior(b, x, R)
poLCA.postClass.C(prior, vp, y)
poLCA.probHat.C(rgivy, y, vp)
poLCA.ylik.C(vp, y)
poLCA.dLL2dBeta.C(rgivy, prior, x)
poLCA.vectorize(probs)
poLCA.unvectorize(vp)
poLCA.compress(y)
poLCA.se(y,x,probs,prior,rgivy)probs for use in C code.probs, for each class. Probabilities are calculated assuming local independence, meaning that for each observation and each class, the item response probabilities are simply multiplied across the manifest variables. Returns a matrix with rows equal to number of observations and columns equal to number of classes specified by nclass in poLCAb in EM algorithm.probs to vector format vp for use in compiled C code.vp to list format probs for use in R.datamat, in the same format (data frame or matrix) as what was inputted, along with the frequency count freq of each unique row in that matrix.poLCA.poLCA